@@ -23,9 +23,9 @@
 # eLyXer containers for Lyx data that output HTML
 
 from util.trace import Trace
-from io.parse import *
+from parse.parser import *
 from io.output import *
-from config import *
+from conf.config import *
 
 
 class Container(object):
